@@ -24,6 +24,8 @@ from skopt.learning.gaussian_process.kernels import (
     DotProduct,
     ConstantKernel,
 )
+from skopt.plots import plot_convergence
+from skopt.utils import use_named_args
 
 # types
 import skopt.learning.gaussian_process.kernels as Kernel
@@ -172,13 +174,16 @@ class BayesianOptimizer:
         self.bestParametersByRegressor = dict()
         bestParameters = {"regressor": None, "score": float("inf"), "parameters": None}
         loadedObjective = partial(
-            objectiveToMinimize,
+            use_named_args(hyperparameterSpaces[model.__class__.__name__])(
+                objectiveToMinimize
+            ),
             **{
                 "model": model,
                 "trainingData": trainingData,
                 "trainingLabels": trainingLabels,
             },
         )
+        optimizedResultList = []
         hyperparameterNames = [parameter.name for parameter in hyperparameterSpaces]
         for regressor in self.regressorCollection.selectedRegressors:
             regressorName = regressor.__class__.__name__ + (
@@ -226,6 +231,7 @@ class BayesianOptimizer:
                         del sampledPoints[index]
                 optimizer.tell(sampledPoints, optimizedParameters)
                 bestScore = min(optimizer.yi)
+                optimizedResult = optimizer.get_result()
                 if self.verbose:
                     print(
                         f"Finished iteration {i+1} of {self.iterations} optimizing {model.__class__.__name__} with {regressorName}. Best score: {bestScore}",
@@ -248,10 +254,11 @@ class BayesianOptimizer:
                 bestParameters["parameters"] = self.bestParametersByRegressor[
                     regressorName
                 ]
+                optimizedResultList.append(optimizedResult)
         if self.verbose:
             print(
                 f"{model.__class__.__name__} has global best parameters using {bestParameters['regressor']} with score {bestParameters['score']}"
             )
             for name, parameter in bestParameters["parameters"].items():
                 print(f"{name}: {parameter}")
-        return bestParameters
+        return bestParameters, plot_convergence(optimizedResultList)
